max method

Vector3 max(
  1. Vector3 v
)

If this vector's x, y or z value is less than v's x, y or z value, replace that value with the corresponding max value.

Implementation

Vector3 max(Vector3 v) {
  x = math.max(x, v.x);
  y = math.max(y, v.y);
  z = math.max(z, v.z);

  return this;
}