attachShader method
Attaches a shader object to a program object
programSpecifies the program object to which a shader object will be attached.shaderSpecifies the shader object that is to be attached
Implementation
attachShader(int program, int shader) {
return gl.glAttachShader(program, shader);
}