getAttribLocation method

int getAttribLocation(
  1. int program,
  2. String name
)

Returns the location of an attribute variable.

  • program Specifies the program object to be queried.
  • name Points to a null terminated string containing the name of the attribute variable whose location is to be queried.

Implementation

int getAttribLocation(int program, String name) {
  final locationName = name.toNativeUtf8();
  final location = gl.glGetAttribLocation(program, locationName.cast<Int8>());
  calloc.free(locationName);
  return location;
}