getAttribLocation method
Returns the location of an attribute variable.
programSpecifies the program object to be queried.namePoints to a null terminated string containing the name of the attribute variable whose location is to be queried.
Implementation
int getAttribLocation(int program, String name) {
final locationName = name.toNativeUtf8();
final location = gl.glGetAttribLocation(program, locationName.cast<Int8>());
calloc.free(locationName);
return location;
}